# `garf-io` - Writing GarfReport to anywhere

[![PyPI](https://img.shields.io/pypi/v/garf-io?logo=pypi&logoColor=white&style=flat-square)](https://pypi.org/project/garf-io)
[![Downloads PyPI](https://img.shields.io/pypi/dw/garf-io?logo=pypi)](https://pypi.org/project/garf-io/)

`garf-io` handles reading queries and writing `GarfReport` to various local/remote storages.

Currently it supports writing data to the following destination:

* Console
* Local file
    * CSV
    * Json
* Remote file
    * CSV
    * Json
* Databases:
    * BigQuery
    * Any DB supported by SqlAlchemy
* Google Sheets

## Installation

`pip install garf-io`
